@@ -10,7 +10,7 @@ test_that("load_ff_rankings", {
   expect_gt(nrow(player_ids), 6000)
 })
 
-test_that("load_schedules", {
+test_that("load_ff_rankings", {
 
   skip_if_offline("github.com")
   skip_on_cran()
@@ -23,3 +23,17 @@ test_that("load_schedules", {
   expect_s3_class(rankings_week, "tbl_df")
   expect_gt(nrow(rankings_week), 500)
 })
+
+test_that("load_ff_opportunity", {
+
+  skip_if_offline("github.com")
+  skip_on_cran()
+
+  ff_opps_week <- load_ff_opportunity(seasons = TRUE)
+  ff_opps_pbp <- load_ff_opportunity(seasons = 2021, stat_type = "pbp_pass", model_version = "v1.0.0")
+
+  expect_s3_class(ff_opps_week, "tbl_df")
+  expect_gt(nrow(ff_opps_week), 80000)
+  expect_s3_class(ff_opps_pbp, "tbl_df")
+  expect_gt(nrow(ff_opps_pbp), 19000)
+})
