@@ -50,10 +50,21 @@ test_that("all caps names with suffix are cleaned correctly", {
 
 test_that("cleaning home and away columns",{
 
-  s <- load_schedules(2020)
+  s <- data.frame(
+    game_id = c("2020_20_TB_GB", "2020_20_BUF_KC", "2020_21_KC_TB"), 
+    game_type = c("CON", "CON", "SB"), 
+    away_team = c("TB", "BUF", "KC"), 
+    away_score = c(31L, 24L, 9L), 
+    home_team = c("GB", "KC", "TB"), 
+    home_score = c(26L, 38L, 31L), 
+    location = c("Home", "Home", "Neutral"), 
+    result = c(-5L, 14L, 22L), 
+    spread_line = c(3, 3, -3)
+  )
   c <- clean_homeaway(s, invert = c("result","spread_line"))
 
   expect_equal(nrow(c),nrow(s)*2)
   expect(all(!grepl(x = names(c),pattern = "^home_")),"Error: `home_` was found in `names(c)`")
-
+  expect_true("neutral" %in% c$location)
+  expect_identical(class(c), class(s))
 })
